@@ -32,15 +32,15 @@ class BillingRecord(models.Model):
     linked_account_id = models.BigIntegerField('Linked Account ID', null=True, blank=True)
     operation = models.CharField('Read ACL', null=True, blank=True, max_length=255)
     payer_account_id = models.BigIntegerField('Payer Account ID', null=True, blank=True)
-    pricing_plan_id = models.IntegerField('Pricing Plan ID', null=True, blank=True)
+    pricing_plan_id = models.BigIntegerField('Pricing Plan ID', null=True, blank=True)
     product_name = models.CharField('Product Name', null=True, blank=True, max_length=255)
     rate = models.FloatField('Rate', null=True, blank=True)
-    rate_id = models.IntegerField('Rate ID', null=True, blank=True)
+    rate_id = models.BigIntegerField('Rate ID', null=True, blank=True)
     record_id = models.CharField('Record ID', null=False, blank=False, unique=True, max_length=255) # This is the magic
     record_type = models.CharField('Record Type', null=True, blank=True, max_length=255)
     reserved_instance = models.CharField('Reserved Instance', null=True, blank=True, max_length=255)
     resource_id = models.CharField('Resource ID', null=True, blank=True, max_length=255)
-    subscription_id = models.IntegerField('Subscription ID', null=True, blank=True)
+    subscription_id = models.BigIntegerField('Subscription ID', null=True, blank=True)
     usage_end_date = models.DateTimeField('Usage End Date', null=True, blank=True)
     usage_quantity = models.FloatField('Usage Quantity', null=True, blank=True)
     usage_start_date = models.DateTimeField('Usage Start Date', null=True, blank=True)
